==> aws-cdk-lib-2.0.0-rc.14-sources.jar: software/amazon/awscdk/services/ec2/InitCommandWaitDuration.java <==
package software.amazon.awscdk.services.ec2;

/**
 * (experimental) Represents a duration to wait after a command has finished, in case of a reboot (Windows only).
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T10:24:20.358Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_ec2.InitCommandWaitDuration")
public abstract class InitCommandWaitDuration extends software.amazon.jsii.JsiiObject {

    protected InitCommandWaitDuration(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected InitCommandWaitDuration(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected InitCommandWaitDuration() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * (experimental) cfn-init will exit and resume only after a reboot.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.InitCommandWaitDuration forever() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.InitCommandWaitDuration.class, "forever", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.InitCommandWaitDuration.class));
    }

    /**
     * (experimental) Do not wait for this command.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.InitCommandWaitDuration none() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.InitCommandWaitDuration.class, "none", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.InitCommandWaitDuration.class));
    }

    /**
     * (experimental) Wait for a specified duration after a command.
     * <p>
     * @param duration This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.InitCommandWaitDuration of(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.Duration duration) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.InitCommandWaitDuration.class, "of", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.InitCommandWaitDuration.class), new Object[] { java.util.Objects.requireNonNull(duration, "duration is required") });
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.ec2.InitCommandWaitDuration {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/ec2/InitCommandWaitDuration.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Represents a duration to wait after a command has finished, in case of a reboot (Windows only).
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.ec2.*;
 * InitCommandWaitDuration initCommandWaitDuration = InitCommandWaitDuration.forever();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:09.284Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_ec2.InitCommandWaitDuration")
public abstract class InitCommandWaitDuration extends software.amazon.jsii.JsiiObject {

    protected InitCommandWaitDuration(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected InitCommandWaitDuration(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected InitCommandWaitDuration() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * cfn-init will exit and resume only after a reboot.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.InitCommandWaitDuration forever() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.InitCommandWaitDuration.class, "forever", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.InitCommandWaitDuration.class));
    }

    /**
     * Do not wait for this command.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.InitCommandWaitDuration none() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.InitCommandWaitDuration.class, "none", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.InitCommandWaitDuration.class));
    }

    /**
     * Wait for a specified duration after a command.
     * <p>
     * @param duration This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.InitCommandWaitDuration of(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.Duration duration) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.InitCommandWaitDuration.class, "of", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.InitCommandWaitDuration.class), new Object[] { java.util.Objects.requireNonNull(duration, "duration is required") });
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.ec2.InitCommandWaitDuration {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }
    }
}
